OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Esto puede solucionarse fácilmente dándole al servidor permisos de escritura del directorio de configuración",
    "See %s" : "Mirar %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Esto puede solucionarse fácilmente %sotorgándole permisos de escritura al directorio de configuración%s.",
    "Sample configuration detected" : "Ejemplo de configuración detectado",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto puede arruinar su instalación y es un caso para el que no se brinda soporte. Lea la documentación antes de hacer cambios en config.php",
    "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferior que %s la requerida.",
    "%sbit or higher PHP required." : "Se requiere PHP %sbit o superior.",
    "Following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
    "The command line tool %s could not be found" : "No se encontró la herramienta %s de línea de comandos",
    "The library %s is not available." : "La biblioteca %s no está disponible",
    "Library %s with a version higher than %s is required - available version %s." : "Biblioteca %s con una versión superior que %s la requerida - versión disponible %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Biblioteca %s con una versión inferior que %s la requerida - versión disponible %s.",
    "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
    "ownCloud %s or higher is required." : "Se requiere ownCloud %s o superior.",
    "ownCloud %s or lower is required." : "Se requiere ownCloud %s o una versión inferior.",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "Avatar image is not square" : "La imagen de avatar no es un cuadrado",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["Hace %n día","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["Hace %n año","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo con id: %s no existe. Por favor habilítelo en los ajustes de sus aplicaciones o contáctese con su administrador.",
    "Builtin" : "Incorporado",
    "None" : "Ninguno",
    "Username and password" : "Nombre de usuario y contraseña",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Log-in credentials, save in session" : "Credenciales de login, guardar en la sesión",
    "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "4-byte characters are not supported in file names" : " No están permitidos caractéres de 4-bytes",
    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "__language_name__" : "Castellano",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "Archive does not contain a directory named %s" : "El archivo no contiene un directorio llamado %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Ninguna ruta especificada al instalar la aplicación desde el fichero local",
    "Archives of type %s are not supported" : "Los ficheros de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Falló la apertura ded fichero mientras se instalaba la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un fichero info.xml",
    "App cannot be installed because appinfo file cannot be read." : "La app no puede ser instalada debido a que no se puede leer la información de la app.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma no pudo ser evaluada. Por favor, contacte con el desarrollador de la aplicación y compruebe su pantalla de administración.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "La App no se puede instalar debido a que la versión de info.xml no es la misma que la versión reportada por la App Store.",
    "No license key available." : "La Clave de licencia no está disponible",
    "Invalid license key!" : "La clave de licencia no es válida",
    "Apps" : "Aplicaciones",
    "General" : "General",
    "Storage" : "Almacenamiento",
    "Security" : "Seguridad",
    "User Authentication" : "Autentificación de Usuario",
    "Encryption" : "Cifrado",
    "Workflows & Tags" : "Workflows & Tags",
    "Sharing" : "Compartiendo",
    "Search" : "Buscar",
    "Help & Tips" : "Ayuda & Trucos",
    "Additional" : "Adicional",
    "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s enter the database name or connection string." : "%s introduzca el nombre de la base de datos o cadena de conexión.",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s No está soportado y %s no funcionará adecuadamente en esta plataforma . Use bajo su propia responsabilidad.",
    "For the best results, please consider using a GNU/Linux server instead." : "Para resultados óptimos, considere utilizar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con arhivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
    "Can't create or write into the apps-external directory %s" : "No puedo crear o escribir en la carpeta externa %s",
    "Can't update %s - it is a directory" : "No es posible actualizar %s -  es una carpeta",
    "Can't update %s" : "No se puede actualizar %s",
    "Invalid Federated Cloud ID" : "ID Nube federada inválida",
    "Internal mail notification for shared files is not allowed" : "No se permite la notificación por correo interno para archivos compartidos",
    "%s shared »%s« with you" : "%s ha compartido »%s« contigo",
    "Public link mail notification is not allowed" : "No se permite la notificación por correo de enlaces públicos",
    "%s via %s" : "%s vía %s",
    "Sharing %s failed, because the backend does not allow shares from type %d" : "Compartir %s ha fallado porque el mecanismo no permite compartidos del tipo %d",
    "Sharing %s failed, because the file does not exist" : "No se pudo compartir %s porque el archivo no existe",
    "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
    "Sharing %s failed, because you can not share with yourself" : "Se falló al compartir %s, porque no puedes compartir contigo mismo",
    "Sharing %s failed, because the user %s does not exist" : "Se ha fallado al compartir %s, ya que el usuario %s no existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se ha fallado al compartir %s, ya que el usuario %s no es miembro de ningún grupo del que %s sea miembro",
    "Sharing %s failed, because this item is already shared with %s" : "Se falló al compartir %s, ya que este elemento ya está compartido con %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartiendo %s falló, porque este objeto ya se comparte con el usuario %s",
    "Sharing %s failed, because the group %s does not exist" : "Se falló al compartir %s, ya que el grupo %s no existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Se falló al compartir %s, ya que %s no es miembro del grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Es necesario definir una contraseña para crear un enlace publico. Solo los enlaces protegidos están permitidos",
    "Sharing %s failed, because sharing with links is not allowed" : "Se falló al compartir %s, ya que no está permitida la compartición con enlaces",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Compartir%s ha fallado, no encuentro %s, revise lo escrito y/o que el servidor este disponible..",
    "Share type %s is not valid for %s" : "Compartir tipo %s no es válido para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "La configuración de permisos para %s ha fallado, ya que los permisos superan los permisos dados a %s",
    "Setting permissions for %s failed, because the item was not found" : "La configuración de permisos para %s ha fallado, ya que no se encontró el elemento ",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No se puede fijar fecha de caducidad. Los archivos compartidos no pueden caducar más tarde de %s de ser compartidos",
    "Cannot set expiration date. Expiration date is in the past" : "No se puede fijar la fecha de caducidad. La fecha de caducidad está en el pasado.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "No se puede eliminar la fecha de caducidad. Los archivos compartidos deben tener una fecha de caducidad.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartido %s debe implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "El motor compartido %s no se ha encontrado",
    "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
    "Sharing failed, because the user %s is the original sharer" : "Se ha fallado al compartir, ya que el usuario %s es el compartidor original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se ha fallado al compartir %s, ya que los permisos superan los permisos otorgados a %s",
    "Sharing %s failed, because resharing is not allowed" : "Fallo al compartir %s, ya que no está permitido volverlo a compartir",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se ha fallado al compartir %s porque el motor compartido para %s podría no encontrar su origen",
    "Sharing %s failed, because the file could not be found in the file cache" : "Se ha fallado al compartir %s, ya que el archivo no pudo ser encontrado en el cache de archivo",
    "Invalid permissions" : "Permisos no válidos",
    "Cannot remove all permissions" : "No puedo eliminar todos los permisos",
    "Cannot set the requested share permissions for %s" : "No se pudieron establecer los permisos para compartir %s",
    "Cannot set the requested share attributes for %s" : "No se pudieron establecer los atributos de la compartición para %s",
    "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
    "Cannot set expiration date more than %s days in the future" : "No se puede fijar la fecha de caducidad más de %s días en el futuro.",
    "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "Solo se permiten los siguientes caracteres en el nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
    "The username must be at least 3 characters long" : "El nombre de usuario debe tener al menos 3 carácteres",
    "The username can not be longer than 64 characters" : "El nombre de usuario no puede tener mas de 64 caracteres,",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The username is already being used" : "El nombre de usuario ya está en uso",
    "Login canceled by app" : "Login cancelado por la app",
    "User disabled" : "Usuario deshabilitado",
    "Settings" : "Ajustes",
    "Users" : "Usuarios",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La app \"%s\" no puede instalarse porque las siguientes dependencias no están cumplimentadas: %s",
    "A safe home for all your data" : "Un lugar seguro para todos sus datos",
    "Imprint" : "Imprimir",
    "Privacy Policy" : "Política de privacidad",
    "File is currently busy, please try again later" : "Archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
    "Access to this resource or one of its sub-items has been denied." : "El acceso a este recurso o uno de sus sub-elementos ha sido denegado.",
    "File cannot be downloaded" : "El archivo no puede ser descargado",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
    "Unknown user" : "Usuario desconocido",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory" : "No se puede escribir el el directorio de configuración",
    "Cannot create \"data\" directory" : "No puedo crear del directorio \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Normalmente esto se puede solucionar  <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dándole al servidor web permisos de escritura en todo el directorio o el directorio 'root'</a>",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Los permisos normalmente puede solucionarse %sdándole al servidor permisos de escritura del directorio raíz%s.",
    "Setting locale to %s failed" : "Falló la activación del idioma %s ",
    "Please install one of these locales on your system and restart your webserver." : "Instale uno de estos idiomas en su sistema y reinicie su servidor web.",
    "Please ask your server administrator to install the module." : "Consulte al administrador de su servidor para instalar el módulo.",
    "PHP module %s not installed." : "El módulo PHP %s no está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "La opción PHP \"%s\" no es \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustando esta opción en php.ini permitirá que ownCloud vuelva a funcionar",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está dispuesta en \"%s\" en lugar del valor esperado \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para solucionarlo, defina la función <code>mbstring.func_overload</code> a <code>0</code> en su php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 es requerido en esta o en versiones superiores. Ahora mismo tienes instalada %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este error, actualiza la versión de tu libxml2 y reinicia el servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
    "Please ask your server administrator to restart the web server." : "Consulte al administrador de su servidor para reiniciar el servidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL 9 o superior requerido.",
    "Please upgrade your database version" : "Actualice su versión de base de datos.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambie los permisos a 0770 para que el directorio no se pueda mostrar para otros usuarios.",
    "Your Data directory is readable by other users" : "El directorio de datos se puede leer por otros usuarios.",
    "Your Data directory must be an absolute path" : "El directorio de datos debe ser una ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
    "Your Data directory  is invalid" : "El directorio de datos no es válido",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifique que el directorio de datos contiene un archivo \".ocdata\" en su directorio raíz.",
    "User unknown" : "Usuario desconocido",
    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
    "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamiento no se encuentra disponible temporalmente",
    "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
    "\"%s\" is locked" : "\"%s\" está bloqueado"
},
"nplurals=2; plural=(n != 1);");
